@@ -11,15 +11,15 @@ from subprocess import Popen
 
 
 class RAMPParser(argparse.ArgumentParser):
-
     @property  # type: ignore
     def epilog(self):
         """Add subcommands to epilog on request
 
         Avoids searching PATH for subcommands unless help output is requested.
         """
-        return 'Available subcommands:\n    - {}'.format(
-            '\n    - '.join(list_subcommands()))
+        return "Available subcommands:\n    - {}".format(
+            "\n    - ".join(list_subcommands())
+        )
 
     @epilog.setter
     def epilog(self, x):
@@ -31,13 +31,15 @@ def ramp_parser():
     parser = RAMPParser(
         description="RAMP: collaborative data science challenges",
         # use raw formatting to preserver newlines in the epilog
-        formatter_class=argparse.RawDescriptionHelpFormatter)
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
     group = parser.add_mutually_exclusive_group(required=True)
     # don't use argparse's version action because it prints to stderr on py2
     # group.add_argument('--version', action='store_true',
     #                    help="show the ramp command's version and exit")
-    group.add_argument('subcommand', type=str, nargs='?',
-                       help='the subcommand to launch')
+    group.add_argument(
+        "subcommand", type=str, nargs="?", help="the subcommand to launch"
+    )
 
     return parser
 
@@ -58,19 +60,18 @@ def list_subcommands():
         except OSError:
             continue
         for name in names:
-            if name.startswith('ramp-'):
-                if sys.platform.startswith('win'):
+            if name.startswith("ramp-"):
+                if sys.platform.startswith("win"):
                     # remove file-extension on Windows
                     name = os.path.splitext(name)[0]
-                subcommand_tuples.add(tuple(name.split('-')[1:]))
+                subcommand_tuples.add(tuple(name.split("-")[1:]))
     # build a set of subcommand strings, excluding subcommands whose parents
     # are defined
     subcommands = set()
     # Only include `jupyter-foo-bar` if `jupyter-foo` is not already present
     for sub_tup in subcommand_tuples:
-        if not any(sub_tup[:i] in subcommand_tuples
-                   for i in range(1, len(sub_tup))):
-            subcommands.add('-'.join(sub_tup))
+        if not any(sub_tup[:i] in subcommand_tuples for i in range(1, len(sub_tup))):
+            subcommands.add("-".join(sub_tup))
     return sorted(subcommands)
 
 
@@ -80,7 +81,7 @@ def _execvp(cmd, argv):
     Python provides execvp on Windows, but its behavior is problematic
     (Python bug#9148).
     """
-    if sys.platform.startswith('win'):
+    if sys.platform.startswith("win"):
         # PATH is ignored when shell=False,
         # so rely on shutil.which
         try:
@@ -89,11 +90,12 @@ def _execvp(cmd, argv):
             from .utils.shutil_which import which
         cmd_path = which(cmd)
         if cmd_path is None:
-            raise OSError('%r not found' % cmd, errno.ENOENT)
+            raise OSError("%r not found" % cmd, errno.ENOENT)
         p = Popen([cmd_path] + argv[1:])
         # Don't raise KeyboardInterrupt in the parent process.
         # Set this after spawning, to avoid subprocess inheriting handler.
         import signal
+
         signal.signal(signal.SIGINT, signal.SIG_IGN)
         p.wait()
         sys.exit(p.returncode)
@@ -113,21 +115,22 @@ def _path_with_self():
         # include realpath, if `ramp` is a symlinkxecvp(command, sys.argv[1:])
         scripts.append(os.path.realpath(scripts[0]))
 
-    path_list = (os.environ.get('PATH') or os.defpath).split(os.pathsep)
+    path_list = (os.environ.get("PATH") or os.defpath).split(os.pathsep)
     for script in scripts:
         bindir = os.path.dirname(script)
-        if (os.path.isdir(bindir)
-                and os.access(script, os.X_OK)):  # only if it's a script
+        if os.path.isdir(bindir) and os.access(
+            script, os.X_OK
+        ):  # only if it's a script
             # ensure executable's dir is on PATH
             # avoids missing subcommands when ramp is run via absolute path
             path_list.insert(0, bindir)
-    os.environ['PATH'] = os.pathsep.join(path_list)
+    os.environ["PATH"] = os.pathsep.join(path_list)
     return path_list
 
 
 def main():
     _path_with_self()  # ensure executable is on PATH
-    if len(sys.argv) > 1 and not sys.argv[1].startswith('-'):
+    if len(sys.argv) > 1 and not sys.argv[1].startswith("-"):
         # Don't parse if a subcommand is given
         # Avoids argparse gobbling up args passed to subcommand, such as `-h`.
         subcommand = sys.argv[1]
@@ -144,12 +147,12 @@ def main():
         parser.print_usage(file=sys.stderr)
         sys.exit("subcommand is required")
 
-    command = 'ramp-' + subcommand
+    command = "ramp-" + subcommand
     try:
         _execvp(command, sys.argv[1:])
     except OSError as e:
         sys.exit("Error executing ramp command %r: %s" % (subcommand, e))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
